@@ -10,7 +10,7 @@
 #ifndef _BONOBO_UI_COMPONENT_H_
 #define _BONOBO_UI_COMPONENT_H_
 
-#include <glib-object.h>
+#include <gtk/gtk.h>
 #include <bonobo/bonobo-object.h>
 #include <bonobo/bonobo-ui-node.h>
 
@@ -45,6 +45,8 @@ typedef struct {
 
 	POA_Bonobo_UIComponent__epv epv;
 
+	gpointer dummy[6];
+
 	/* Signals */
 	void (*exec_verb) (BonoboUIComponent *comp,
 			   const char        *cname);
@@ -88,9 +90,6 @@ typedef struct {
 	gboolean (*exists) (BonoboUIComponent *component,
 			    const char        *path,
 			    CORBA_Environment *ev);
-	
-
-	gpointer            dummy;
 } BonoboUIComponentClass;
 
 GType              bonobo_ui_component_get_type        (void) G_GNUC_CONST;
@@ -178,12 +177,17 @@ BonoboUINode      *bonobo_ui_component_get_tree     (BonoboUIComponent  *compone
 void               bonobo_ui_component_object_set   (BonoboUIComponent  *component,
 						     const char         *path,
 						     Bonobo_Unknown      control,
-						     CORBA_Environment  *ev);
+						     CORBA_Environment  *opt_ev);
 
 Bonobo_Unknown     bonobo_ui_component_object_get   (BonoboUIComponent  *component,
 						     const char         *path,
 						     CORBA_Environment  *opt_ev);
 
+void               bonobo_ui_component_widget_set   (BonoboUIComponent  *component,
+						     const char         *path,
+						     GtkWidget          *widget,
+						     CORBA_Environment  *opt_ev);
+
 void               bonobo_ui_component_freeze       (BonoboUIComponent  *component,
 						     CORBA_Environment  *opt_ev);
 
@@ -206,7 +210,7 @@ void               bonobo_ui_component_set_status   (BonoboUIComponent  *compone
 						     CORBA_Environment  *opt_ev);
 
 typedef struct {
-	char          *cname;
+	const char    *cname;
 	BonoboUIVerbFn cb;
 	gpointer       user_data;
 	gpointer       dummy;
