@@ -8,13 +8,15 @@
  * Copyright 2000 Ximian, Inc.
  */
 
+#undef GTK_DISABLE_DEPRECATED
+
 #include <config.h>
 #include <stdlib.h>
 #include <string.h>
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <bonobo/bonobo-ui-xml.h>
 #include <bonobo/bonobo-ui-util.h>
@@ -143,7 +145,7 @@ impl_bonobo_ui_sync_toolbar_state (BonoboUISync     *sync,
 			GtkLabel *label_widget;
 
 			if (!(label_widget = GTK_LABEL (gtk_tool_button_get_label_widget (button_item)))) {
-				label_widget = GTK_LABEL (gtk_label_new (""));
+				label_widget = GTK_LABEL (gtk_label_new (NULL));
 				gtk_tool_button_set_label_widget (button_item, GTK_WIDGET (label_widget));
 			}
 
